@@ -1,6 +1,6 @@
 package Elastic::Model::View;
 {
-  $Elastic::Model::View::VERSION = '0.11';
+  $Elastic::Model::View::VERSION = '0.12';
 }
 
 use Moose;
@@ -72,7 +72,8 @@ has 'fields' => (
     isa     => ArrayRefOfStr,
     coerce  => 1,
     is      => 'rw',
-    default => sub { ['_source'] },
+    lazy    => 1,
+    builder => '_build_fields',
 );
 
 #===================================
@@ -152,6 +153,22 @@ has 'routing' => (
     is     => 'rw',
 );
 
+#===================================
+has 'include_paths' => (
+#===================================
+    is        => 'rw',
+    isa       => ArrayRef [Str],
+    predicate => '_has_include_paths'
+);
+
+#===================================
+has 'exclude_paths' => (
+#===================================
+    is        => 'rw',
+    isa       => ArrayRef [Str],
+    predicate => '_has_exclude_paths'
+);
+
 #===================================
 has 'script_fields' => (
 #===================================
@@ -259,7 +276,8 @@ around [
 
 around [
 #===================================
-    'domain', 'type', 'fields', 'sort', 'routing', 'stats'
+    'domain',        'type', 'fields', 'sort', 'routing', 'stats',
+    'include_paths', 'exclude_paths'
 #===================================
 ] => sub { _clone_args( \&_array_args, @_ ) };
 
@@ -318,6 +336,14 @@ sub _check_no_fields {
         if $val->{fields};
 }
 
+#===================================
+sub _build_fields {
+#===================================
+    my $self = shift;
+    return $self->_has_include_paths
+        || $self->_has_exclude_paths ? [] : ['_source'];
+}
+
 no Moose;
 
 #===================================
@@ -394,6 +420,13 @@ sub _build_search {
         $highlight = { %{ $self->highlighting || {} }, fields => $fields };
     }
 
+    my %partial;
+
+    $partial{include} = $self->include_paths
+        if $self->_has_include_paths;
+    $partial{exclude} = $self->exclude_paths
+        if $self->_has_exclude_paths;
+
     my %args = ( (
             map { $_ => $self->$_ }
                 qw(
@@ -410,7 +443,7 @@ sub _build_search {
         @_,
         version => 1,
         fields  => [ '_parent', '_routing', @{ $self->fields } ],
-
+        ( partial_fields => { _partial_doc => \%partial } ) x !!%partial
     );
 
     return { map { $_ => $args{$_} } grep { defined $args{$_} } keys %args };
@@ -455,7 +488,7 @@ Elastic::Model::View - Views to query your docs in ElasticSearch
 
 =head1 VERSION
 
-version 0.11
+version 0.12
 
 =head1 SYNOPSIS
 
@@ -821,6 +854,27 @@ L<Script fields|http://www.elasticsearch.org/guide/reference/api/search/script-f
 can be generated using the L<mvel|http://mvel.codehaus.org/Language+Guide+for+2.0>
 scripting language. (You can also use L<Javascript, Python and Java|http://www.elasticsearch.org/guide/reference/modules/scripting>.)
 
+=head2 include_paths / exclude_paths
+
+    $new_view    = $view->include_paths('foo.*')
+                        ->exclude_paths('foo.bar.*','baz.*');
+
+    $results     = $new_view->search->as_partials;
+    $partial_obj = $results->next;
+
+If your objects are large, but you only need access to a few attributes to
+eg display search results, you may want to retrieve only the relevant parts of
+each object.  You can specify which parts of the object to include or exclude
+using C<include_paths> and C<exclude_paths>. If either of these is set
+then the full C<_source> field will not be loaded (unless you specify it
+explicitly using L</fields>).
+
+The partial objects returned when L<Elastic::Model::Results/as_partials()>
+is in effect function exactly as real objects, except that they cannot
+be saved.
+
+See C<Partial fields> on L<http://www.elasticsearch.org/guide/reference/api/search/fields.html>.
+
 =head2 routing
 
     $new_view = $view->routing( 'routing_val' );
